
Changelog
---------

0.2 (2014-12-01)
~~~~~~~~~~~~~~~~

 - Adds the ability to toggle markers by clicking on them. Fixes #2.
   [href]

 - Makes sure bogus urls don't lead to an exception. Fixes #3.
   [href]

 - Fixes KML before loading, to avoid common problems found in external
   KML sources.
   [href]

0.1 (2014-10-29)
~~~~~~~~~~~~~~~~

 - Initial release.
   [href]
